@@ -1,13 +1,13 @@
 """
 I/O for XDMF.
-http://www.xdmf.org/index.php/XDMF_Model_and_Format
+https://www.xdmf.org/index.php/XDMF_Model_and_Format
 """
 import os
 import pathlib
 from io import BytesIO
 from xml.etree import ElementTree as ET
 
-import numpy
+import numpy as np
 
 from .._common import cell_data_from_raw, raw_from_cell_data, write_xml
 from .._exceptions import ReadError, WriteError
@@ -77,7 +77,7 @@ class XdmfReader:
             data_type = data_item.get("NumberType")
         else:
             # Default, see
-            # <http://www.xdmf.org/index.php/XDMF_Model_and_Format#XML_Element_.28Xdmf_ClassName.29_and_Default_XML_Attributes>
+            # <https://www.xdmf.org/index.php/XDMF_Model_and_Format#XML_Element_.28Xdmf_ClassName.29_and_Default_XML_Attributes>
             data_type = "Float"
 
         try:
@@ -86,13 +86,15 @@ class XdmfReader:
             precision = "4"
 
         if data_item.get("Format") == "XML":
-            return numpy.fromstring(
-                data_item.text,
-                dtype=xdmf_to_numpy_type[(data_type, precision)],
-                sep=" ",
-            ).reshape(dims)
+            dtype = xdmf_to_numpy_type[(data_type, precision)]
+            if data_item.text.strip() == "":
+                # https://github.com/numpy/numpy/issues/18435
+                data = np.empty((0,), dtype=dtype)
+            else:
+                data = np.fromstring(data_item.text, dtype=dtype, sep=" ")
+            return data.reshape(dims)
         elif data_item.get("Format") == "Binary":
-            return numpy.fromfile(
+            return np.fromfile(
                 data_item.text.strip(), dtype=xdmf_to_numpy_type[(data_type, precision)]
             ).reshape(dims)
         elif data_item.get("Format") != "HDF":
@@ -114,7 +116,7 @@ class XdmfReader:
 
         for key in h5path.split("/"):
             f = f[key]
-        # `[()]` gives a numpy.ndarray
+        # `[()]` gives a np.ndarray
         return f[()]
 
     def read_information(self, c_data):
@@ -129,7 +131,7 @@ class XdmfReader:
             if child.text is None:
                 raise ReadError()
             num_tag = int(child.text)
-            field_data[str_tag] = numpy.array([num_tag, dim])
+            field_data[str_tag] = np.array([num_tag, dim])
         return field_data
 
     def read_xdmf2(self, root):  # noqa: C901
@@ -164,7 +166,7 @@ class XdmfReader:
                 topology_type = c.get("TopologyType")
                 if topology_type == "Mixed":
                     cells = translate_mixed_cells(
-                        numpy.fromstring(
+                        np.fromstring(
                             data_items[0].text,
                             int,
                             int(data_items[0].get("Dimensions")),
@@ -365,7 +367,7 @@ class XdmfWriter:
         if self.data_format == "XML":
             s = BytesIO()
             fmt = dtype_to_format_string[data.dtype.name]
-            numpy.savetxt(s, data, fmt)
+            np.savetxt(s, data, fmt)
             return "\n" + s.getvalue().decode()
         elif self.data_format == "Binary":
             base = os.path.splitext(self.filename)[0]
@@ -408,6 +410,8 @@ class XdmfWriter:
         data_item.text = self.numpy_to_xml_string(points)
 
     def write_cells(self, cells, grid):
+        if len(cells) == 0:
+            return
         if len(cells) == 1:
             meshio_type = cells[0].type
             num_cells = len(cells[0].data)
@@ -440,16 +444,16 @@ class XdmfWriter:
                 TopologyType="Mixed",
                 NumberOfElements=str(total_num_cells),
             )
-            total_num_cell_items = sum(numpy.prod(c.data.shape) for c in cells)
+            total_num_cell_items = sum(np.prod(c.data.shape) for c in cells)
             num_vertices_and_lines = sum(
                 c.data.shape[0] for c in cells if c.type in {"vertex", "line"}
             )
             dim = str(total_num_cell_items + total_num_cells + num_vertices_and_lines)
-            cd = numpy.concatenate(
+            cd = np.concatenate(
                 [
-                    numpy.hstack(
+                    np.hstack(
                         [
-                            numpy.full(
+                            np.full(
                                 (value.shape[0], 2 if key in {"vertex", "line"} else 1),
                                 meshio_type_to_xdmf_index[key],
                             ),
